@@ -10,7 +10,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2020, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2022, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -370,9 +370,9 @@ _SWITCHOVER_USAGE_
     COMMON_MS0035       => "パスワードファイル \"[0]\" の権限が 600 ではありません\n",
     COMMON_MS0036       => "[0] に PostgreSQL コマンドが見つかりません。: [1]\n",
     COMMON_MS0037       => "PostgreSQL [0] には対応していません\n".
-                           "PostgreSQL 12 を使用してください\n",
+                           "PostgreSQL 13 を使用してください\n",
     COMMON_MS0038       => "Pacemaker [0] には対応していません\n".
-                           "Pacemaker 2.0 を使用してください\n",
+                           "Pacemaker 2 を使用してください\n",
     COMMON_MS0039       => "[0] で bindnetaddr ([1]) に対応するネットワークインタフェースが見つかりませんでした\n",
     COMMON_MS0040       => "[0] で bindnetaddr ([1]) に属する IP アドレスの取得に失敗しました\n",
     COMMON_MS0044       => "アーカイブディレクトリの状態を確認できませんでした: [0]\n",
